@@ -30,15 +30,16 @@ static struct _cache_table TRACE_cache_table[] =
 	{ 0x70, 12, "Instruction trace cache:\n\tSize: 12K uOps\t8-way associative." },
 	{ 0x71, 16, "Instruction trace cache:\n\tSize: 16K uOps\t8-way associative." },
 	{ 0x72, 32, "Instruction trace cache:\n\tSize: 32K uOps\t8-way associative." },
-	{ 0, 0, 0 }
+	{ 0x73, 64, "Instruction trace cache:\n\tSize: 64K uOps\t8-way associative." },
+	{ 0, 0, NULL }
 };
 
 static struct _cache_table L1I_cache_table[] =
 {
 	{ 0x6,  8, "L1 Instruction cache:\n\tSize: 8KB\t4-way associative.\n\tline size=32 bytes." },
 	{ 0x8,  16, "L1 Instruction cache:\n\tSize: 16KB\t4-way associative.\n\tline size=32 bytes." },
-	{ 0x30, 32,	"L1 Instruction cache:\n\t:Size 32KB\t8-way associative.\n\tline size=64 bytes." },
-	{ 0, 0, 0 }
+	{ 0x30, 32,	"L1 Instruction cache:\n\tSize 32KB\t8-way associative.\n\tline size=64 bytes." },
+	{ 0, 0, NULL }
 };
 
 static struct _cache_table L1D_cache_table[] =
@@ -50,31 +51,43 @@ static struct _cache_table L1D_cache_table[] =
 	{ 0x66, 8, "L1 Data cache:\n\tSize: 8KB\tSectored, 4-way associative.\n\tline size=64 bytes." },
 	{ 0x67, 16, "L1 Data cache:\n\tSize: 16KB\tSectored, 4-way associative.\n\tline size=64 bytes." },
 	{ 0x68, 32, "L1 Data cache:\n\tSize: 32KB\tSectored, 4-way associative.\n\tline size=64 bytes." },
-	{ 0, 0, 0 }
+	{ 0, 0, NULL }
 };
 
 static struct _cache_table L2_cache_table[] =
 {
 	{ 0x39, 128, "L2 unified cache:\n\tSize: 128KB\t4-way associative.\n\tline size=64 bytes." },
+	{ 0x3a, 192, "L2 unified cache:\n\tSize: 192KB\t6-way associative.\n\tline size=64 bytes." },
 	{ 0x3b, 128, "L2 unified cache:\n\tSize: 128KB\t2-way associative.\n\tline size=64 bytes." },
 	{ 0x3c, 256, "L2 unified cache:\n\tSize: 256KB\t4-way associative.\n\tline size=64 bytes." },
+	{ 0x3d, 384, "L2 unified cache:\n\tSize: 384KB\t6-way associative.\n\tline size=64 bytes." },
+	{ 0x3e, 512, "L2 unified cache:\n\tSize: 512KB\t4-way associative.\n\tline size=64 bytes." },
 	{ 0x41, 128, "L2 unified cache:\n\tSize: 128KB\t4-way associative.\n\tline size=32 bytes." },
 	{ 0x42, 256, "L2 unified cache:\n\tSize: 256KB\t4-way associative.\n\tline size=32 bytes." },
 	{ 0x43, 512, "L2 unified cache:\n\tSize: 512KB\t4-way associative.\n\tline size=32 bytes." },
 	{ 0x44, 1024, "L2 unified cache:\n\tSize: 1MB\t4-way associative.\n\tline size=32 bytes." },
 	{ 0x45, 2048, "L2 unified cache:\n\tSize: 2MB\t4-way associative.\n\tline size=32 bytes." },
-	{ 0x78, 1024, "L2 unified cache:\n\tSize: 1MB\tSectored, 8-way associative.\n\tline size=64 bytes." },
+	{ 0x46, 4096, "L3 unified cache:\n\tSize: 4MB\t4-way associative.\n\tline size=64 bytes." },
+	{ 0x47, 8192, "L3 unified cache:\n\tSize: 8MB\t8-way associative.\n\tline size=64 bytes." },
+	{ 0x49, 4096, "L3 unified cache:\n\tSize: 4MB\t16-way associative.\n\tline size=64 bytes." },
+	{ 0x4a, 6144, "L3 unified cache:\n\tSize: 6MB\t12-way associative.\n\tline size=64 bytes." },
+	{ 0x4b, 8192, "L3 unified cache:\n\tSize: 8MB\t16-way associative.\n\tline size=64 bytes." },
+	{ 0x4c, 12288, "L3 unified cache:\n\tSize: 12MB\t12-way associative.\n\tline size=64 bytes." },
+	{ 0x4d, 16384, "L3 unified cache:\n\tSize: 16MB\t16-way associative.\n\tline size=64 bytes." },
+	{ 0x78, 1024, "L3 unified cache:\n\tSize: 1MB\tSectored, 8-way associative.\n\tline size=64 bytes." },
 	{ 0x79, 128, "L2 unified cache:\n\tSize: 128KB\tSectored, 8-way associative.\n\tline size=64 bytes." },
 	{ 0x7a, 256, "L2 unified cache:\n\tSize: 256KB\tSectored, 8-way associative.\n\tline size=64 bytes." },
 	{ 0x7b, 512, "L2 unified cache:\n\tSize: 512KB\tSectored, 8-way associative.\n\tline size=64 bytes." },
 	{ 0x7c, 1024, "L2 unified cache:\n\tSize: 1MB\tSectored, 8-way associative.\n\tline size=64 bytes." },
+	{ 0x7d, 2048, "L2 unified cache:\n\tSize: 2MB\tSectored, 8-way associative.\n\tline size=64 bytes." },
+	{ 0x7f, 512, "L2 unified cache:\n\tSize: 512KB\t2-way associative.\n\tline size=64 bytes." },
 	{ 0x82, 256, "L2 unified cache:\n\tSize: 256KB\t8-way associative.\n\tline size=32 bytes." },
 	{ 0x83, 512, "L2 unified cache:\n\tSize: 512KB\t8-way associative.\n\tline size=32 bytes." },
 	{ 0x84, 1024, "L2 unified cache:\n\tSize: 1MB\t8-way associative.\n\tline size=32 bytes." },
 	{ 0x85, 2048, "L2 unified cache:\n\tSize: 2MB\t8-way associative.\n\tline size=32 bytes." },
 	{ 0x86, 512, "L2 unified cache:\n\tSize: 512KB\t4-way associative\n\tline size=64 bytes." },
 	{ 0x87, 1024, "L2 unified cache:\n\tSize: 1MB\t8-way associative.\n\tline size=64 bytes." },
-	{ 0, 0, 0 }
+	{ 0, 0, NULL }
 };
 
 static struct _cache_table L3_cache_table[] =
@@ -83,7 +96,7 @@ static struct _cache_table L3_cache_table[] =
 	{ 0x23, 1024, "L3 unified cache:\n\tSize: 1MB\t8-way associative.\n\tline size=64 bytes." },
 	{ 0x25, 2048, "L3 unified cache:\n\tSize: 2MB\t8-way associative.\n\tline size=64 bytes." },
 	{ 0x29, 4096, "L3 unified cache:\n\tSize: 4MB\t8-way associative.\n\tline size=64 bytes." },
-	{ 0, 0, 0 }
+	{ 0, 0, NULL }
 };
 
 static struct _cache_table ITLB_cache_table[] =
@@ -94,7 +107,7 @@ static struct _cache_table ITLB_cache_table[] =
 	{ 0x51, 128, "Instruction TLB: 4K, 2MB or 4MB pages, fully associative, 128 entries." },
 	{ 0x52, 256, "Instruction TLB: 4K, 2MB or 4MB pages, fully associative, 256 entries." },
 	{ 0xb0, 128, "Instruction TLB: 4K pages, 4-way associative, 128 entries." },
-	{ 0, 0, 0 }
+	{ 0, 0, NULL }
 };
 
 static struct _cache_table DTLB_cache_table[] =
@@ -105,7 +118,7 @@ static struct _cache_table DTLB_cache_table[] =
 	{ 0x5c, 128, "Data TLB: 4KB or 4MB pages, fully associative, 128 entries." },
 	{ 0x5d, 256, "Data TLB: 4KB or 4MB pages, fully associative, 256 entries." },
 	{ 0xb3, 128, "Data TLB: 4K pages, 4-way associative, 128 entries." },
-	{ 0, 0, 0 }
+	{ 0, 0, NULL }
 };
 
 static char found_unknown=0;
@@ -152,9 +165,8 @@ static void decode_Intel_cache (int des, struct cpudata *cpu, int output,
 
 static void decode_cache(struct cpudata *cpu, struct _cache_table *table, int output)
 {
-	int i, j, n;
-	long regs[4];
-	unsigned char *dp = (unsigned char *)regs;
+	unsigned int i, j, n;
+	unsigned long regs[4];
 
 	/* Decode TLB and cache info */
 	cpuid (cpu->number, 2, &regs[0], &regs[1], &regs[2], &regs[3]);
@@ -167,20 +179,22 @@ static void decode_cache(struct cpudata *cpu, struct _cache_table *table, int ou
 
 		/* If bit 31 is set, this is an unknown format */
 		for (j=0; j<3; j++)
-			if (regs[j] < 0)
+			if (regs[j] & 0x80000000)
 				regs[j] = 0;
 
 		/* Byte 0 is level count, not a descriptor */
-		for (j=1; j<16; j++)
-			if (dp[j]!=0)
-				decode_Intel_cache (dp[j], cpu, output, table);
+		for (j=1; j<16; j++) {
+			unsigned char val = regs[j / 4] >> (unsigned int)(8 * (j % 4));
+			if (val)
+				decode_Intel_cache (val, cpu, output, table);
+		}
 	}
 }
 
 
 void decode_Intel_caches (struct cpudata *cpu, int output)
 {
-	int i;
+	unsigned int i;
 
 	if (cpu->maxi < 2)
 		return;
@@ -201,7 +215,7 @@ void decode_Intel_caches (struct cpudata *cpu, int output)
 
 	for (i=0; i<256; i++) {
 		if (unknown_array[i]==1)
-			printf ("%d ", i);
+			printf ("%02x ", i);
 	}
 	printf ("\n");
 	decode_cache (cpu, DTLB_cache_table, output);
